from distutils.core import setup

setup(
	name='pytictactoe',
	version='1.0.3',
	packages=['pytictactoe'],
	scripts=['pyttt.py'],
	license='Creative Commons Attribution-Noncommercial-Share Alike License',
	long_description='This is the Best Graphical Tic-Tac-Toe Game Ever',
)
